==> dokuwiki-2011.05.25a.tgz: dokuwiki/inc/lang/id/lang.php <==
<?php
/**
 * Indonesian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author mubaidillah <mubaidillah@gmail.com>
 * @author Irwan Butar Butar <irwansah.putra@gmail.com>
 * @author Yustinus Waruwu <juswaruwu@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '\'';
$lang['singlequoteclosing']    = '\'';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Edit halaman ini';
$lang['btn_source']            = 'Lihat sumber halaman';
$lang['btn_show']              = 'Tampilkan halaman';
$lang['btn_create']            = 'Buat halaman baru';
$lang['btn_search']            = 'Cari';
$lang['btn_save']              = 'Simpan';
$lang['btn_preview']           = 'Preview';
$lang['btn_top']               = 'kembali ke atas';
$lang['btn_newer']             = '<< lebih lanjut';
$lang['btn_older']             = 'sebelumnya >>';
$lang['btn_revs']              = 'Revisi-revisi lama';
$lang['btn_recent']            = 'Perubahan terbaru';
$lang['btn_upload']            = 'Upload';
$lang['btn_cancel']            = 'Batal';
$lang['btn_index']             = 'Indeks';
$lang['btn_secedit']           = 'Edit';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Keluar';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Ubah';
$lang['btn_delete']            = 'Hapus';
$lang['btn_back']              = 'Kembali';
$lang['btn_backlink']          = 'Backlinks';
$lang['btn_backtomedia']       = 'Kembali ke Pilihan Mediafile';
$lang['btn_subscribe']         = 'Ikuti Perubahan';
$lang['btn_unsubscribe']       = 'Berhenti Ikuti Perubahan';
$lang['btn_profile']           = 'Ubah Profil';
$lang['btn_reset']             = 'Reset';
$lang['btn_resendpwd']         = 'Kirim password baru';
$lang['btn_draft']             = 'Edit draft';
$lang['btn_draftdel']          = 'Hapus draft';
$lang['btn_register']          = 'Daftar';
$lang['loggedinas']            = 'Login sebagai ';
$lang['user']                  = 'Username';
$lang['pass']                  = 'Password';
$lang['newpass']               = 'Password baru';
$lang['oldpass']               = 'Konfirmasi password';
$lang['passchk']               = 'sekali lagi';
$lang['remember']              = 'Ingat saya';
$lang['fullname']              = 'Nama lengkap';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Profil User';
$lang['badlogin']              = 'Maaf, username atau password salah.';
$lang['minoredit']             = 'Perubahan Minor';
$lang['draftdate']             = 'Simpan draft secara otomatis';
$lang['regmissing']            = 'Maaf, Anda harus mengisi semua field.';
$lang['reguexists']            = 'Maaf, user dengan user login ini telah ada.';
$lang['regsuccess']            = 'User telah didaftarkan dan password telah dikirim ke email Anda.';
$lang['regsuccess2']           = 'User telah dibuatkan.';
$lang['regmailfail']           = 'Kami menemukan kesalahan saat mengirimkan password ke alamat email Anda. Mohon hubungi administrator.';
$lang['regbadmail']            = 'Alamat email yang Anda masukkan tidak valid - jika menurut Anda hal ini adalah kesalahan sistem, mohon hubungi admin.';
$lang['regbadpass']            = 'Passwod yang dimasukkan tidak sama. Silahkan ulangi lagi.';
$lang['regpwmail']             = 'Password DokuWiki Anda';
$lang['reghere']               = 'Anda belum mempunyai account? silahkan ';
$lang['profna']                = 'Wiki ini tidak mengijinkan perubahan profil.';
$lang['profnochange']          = 'Tidak ada perubahan.';
$lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
$lang['profchanged']           = 'Profil User berhasil diubah.';
$lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
$lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
$lang['resendpwd']             = 'Kirim password baru untuk';
$lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
$lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
$lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
$lang['resendpwdconfirm']      = 'Link konfirmasi telah dikirim melalui email.';
$lang['resendpwdsuccess']      = 'Password baru Anda telah dikirim melalui email.';
$lang['txt_upload']            = 'File yang akan diupload';
$lang['txt_filename']          = 'Masukkan nama wiki (opsional)';
$lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
$lang['lockedby']              = 'Sedang dikunci oleh';
$lang['lockexpire']            = 'Penguncian artikel sampai dengan';
$lang['willexpire']            = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
$lang['js']['notsavedyet']     = "Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?";
$lang['rssfailed']             = 'Error terjadi saat mengambil feed: ';
$lang['nothingfound']          = 'Tidak menemukan samasekali.';
$lang['mediaselect']           = 'Pilihan Mediafile';
$lang['fileupload']            = 'Mediafile Upload';
$lang['uploadsucc']            = 'Upload sukses';
$lang['uploadfail']            = 'Upload gagal. Apakah hak ijinnya salah?';
$lang['uploadwrong']           = 'Upload ditolak. Ekstensi file ini tidak diperbolehkan!';
$lang['uploadexist']           = 'File telah ada. Tidak mengerjakan apa-apa.';
$lang['uploadbadcontent']      = 'Isi file yang diupload tidak cocok dengan ekstensi file %s.';
$lang['uploadspam']            = 'File yang diupload diblok oleh spam blacklist.';
$lang['uploadxss']             = 'File yang diupload diblok karena kemungkinan isi yang berbahaya.';
$lang['deletesucc']            = 'File "%s" telah dihapus.';
$lang['deletefail']            = '"%s" tidak dapat dihapus - cek hak aksesnya.';
$lang['mediainuse']            = 'File "%s" belum dihapus - file ini sedang digunakan.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'File tersedia didalam';
$lang['js']['keepopen']        = 'Biarkan window terbuka dalam pemilihan';
$lang['js']['hidedetails']     = 'Sembunyikan detil';
$lang['mediausage']            = 'Gunakan sintaks berikut untuk me-refer ke file ini';
$lang['mediaview']             = 'Tampilkan file asli';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Upload file ke namespace ini. Untuk menbuat namespace baru, tambahkan namanya didepanpada nama file "Upload as" dipisahkan dengan titik dua (:).';
$lang['mediaextchange']        = 'Ektensi file berubah dari .%s ke .%s';
$lang['reference']             = 'Referensi untuk';
$lang['ref_inuse']             = 'File tidak dapat dihapus karena sedang digunakan oleh halaman:';
$lang['ref_hidden']            = 'Beberapa referensi ada didalam halaman yang tidak diijinkan untuk Anda baca.';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Matching pagenames';
$lang['toc']                   = 'Daftar isi';
$lang['current']               = 'sekarang';
$lang['yours']                 = 'Versi Anda';
$lang['diff']                  = 'Tampilkan perbedaan dengan versi sekarang';
$lang['diff2']                 = 'Tampilkan perbedaan diantara revisi terpilih';
$lang['line']                  = 'Baris';
$lang['breadcrumb']            = 'Jejak';
$lang['youarehere']            = 'Anda disini';
$lang['lastmod']               = 'Terakhir diubah';
$lang['by']                    = 'oleh';
$lang['deleted']               = 'terhapus';
$lang['created']               = 'dibuat';
$lang['restored']              = 'revisi lama ditampilkan kembali';
$lang['external_edit']         = 'Perubahan eksternal';
$lang['summary']               = 'Edit summary';
$lang['mail_newpage']          = 'Halaman ditambahkan:';
$lang['mail_changed']          = 'Halaman diubah:';
$lang['mail_new_user']         = 'User baru:';
$lang['mail_upload']           = 'Berkas di-upload:';
$lang['js']['nosmblinks']            = "Link ke share Windows hanya bekerja di Microsoft Internet Explorer.\nAnda masih dapat mengcopy and paste linknya.";
$lang['qb_bold']               = 'Tebal';
$lang['qb_italic']             = 'Miring';
$lang['qb_underl']             = 'Garis Bawah';
$lang['qb_code']               = 'Kode';
$lang['qb_strike']             = 'Text Tercoret';
$lang['qb_h1']                 = 'Level 1 Headline';
$lang['qb_h2']                 = 'Level 2 Headline';
$lang['qb_h3']                 = 'Level 3 Headline';
$lang['qb_h4']                 = 'Level 4 Headline';
$lang['qb_h5']                 = 'Level 5 Headline';
$lang['qb_link']               = 'Link Internal';
$lang['qb_extlink']            = 'Link External';
$lang['qb_hr']                 = 'Garis Horisontal';
$lang['qb_ol']                 = 'Item Berurutan';
$lang['qb_ul']                 = 'Item Tidak Berurutan';
$lang['qb_media']              = 'Tambahkan gambar atau file lain';
$lang['qb_sig']                = 'Sisipkan tanda tangan';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Karakter Khusus';
$lang['js']['del_confirm']           = 'Hapus tulisan ini?';
$lang['admin_register']        = 'Tambah user baru';
$lang['metaedit']              = 'Edit Metadata';
$lang['metasaveerr']           = 'Gagal menulis metadata';
$lang['metasaveok']            = 'Metadata tersimpan';
$lang['img_backto']            = 'Kembali ke';
$lang['img_title']             = 'Judul';
$lang['img_caption']           = 'Label';
$lang['img_date']              = 'Tanggal';
$lang['img_fname']             = 'Nama file';
$lang['img_fsize']             = 'Ukuran';
$lang['img_artist']            = 'Tukang foto';
$lang['img_copyr']             = 'Hakcipta';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Katakunci';
$lang['subscribe_success']     = 'Penambahan %s ke data subsripsi untuk %s';
$lang['subscribe_error']       = 'Gagal menambahkan %s ke data subsripsi untuk %s';
$lang['subscribe_noaddress']   = 'Tidak ditemukan alamat yang berhubungan dengan login Anda, Anda tidak dapat menambahkan daftar subscription';
$lang['unsubscribe_success']   = 'Menghapus %s dari daftar subscription untuk %s';
$lang['unsubscribe_error']     = 'Gagal menghapus %s dari daftar subscription untuk %s';
$lang['authmodfailed']         = 'Konfigurasi autentikasi user tidak valid. Harap informasikan admin Wiki Anda.';
$lang['authtempfail']          = 'Autentikasi user saat ini sedang tidak dapat digunakan. Jika kejadian ini berlanjut, Harap informasikan admin Wiki Anda.';
$lang['i_chooselang']          = 'Pilih bahasa';
$lang['i_installer']           = 'Instalasi DokuWiki';
$lang['i_wikiname']            = 'Nama Wiki';
$lang['i_enableacl']           = 'Aktifkan ACL (disarankan)';
$lang['i_problems']            = 'Terdapat beberapa kesalahan seperti berikut. Anda tidak dapat melanjutkan sampai kesalahan tersebut diperbaiki.';
$lang['i_modified']            = 'Untuk alasan keamanan, skrip ini hanya dapat dijalankan pada instalasi DikuWiki baru dan belum di modifikasi. Silahkan meng-ekstrak kembali berkasi dari halaman dowload, atau lihat   <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a> ';
$lang['i_funcna']              = 'Fungsi PHP <code>%s</code> tidak tersedia. Mungkin dinonaktifkan oleh layanan hosting Anda?';
$lang['i_phpver']              = 'Versi PHP Anda <code>%s</code> lebih rendah dari yang dibutuhkan <code>%s</code>. Mohon melakukan upgrade.';
$lang['i_permfail']            = '<code>%s</code> tidak dapat ditulis oleh DokuWiki. Anda harus memperbaiki konfigurasi hak akses untuk direktori tersebut.';
$lang['i_confexists']          = '<code>%s</code> sudah ada';
$lang['i_writeerr']            = 'Tidak dapat membuat <code>%s</code>. Anda harus memeriksa konfigurasi hak akses direktori/berkas dan membuatnya secara manual.';
$lang['i_badhash']             = 'dokuwiki.php tidak dikenal atau sudah diubah (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - tidak valid atau belum diisi';
$lang['i_success']             = 'Konfigurasi telah berhasil. Anda boleh menghapus berkas install.php sekarang. Lanjutkan ke <a href="doku.php">DokuWiki baru Anda</a>.';
$lang['i_failure']             = 'Terdapat beberapa kesalahan dalam menulis berkas konfigurasi. Anda harus memperbaikinnya sendiri sebelum dapat menggunakan <a href="doku.php">DokuWiki baru Anda</a>.';
$lang['i_policy']              = 'Policy ACL awal';
$lang['i_pol0']                = 'Wiki Terbuka (baca, tulis, upload untuk semua orang)';
$lang['i_pol1']                = 'Wiki Publik (baca untuk semua orang, tulis dan upload untuk pengguna terdaftar)';
$lang['i_pol2']                = 'Wiki Privat (baca, tulis dan upload hanya untuk pengguna terdaftar)';
$lang['i_retry']               = 'Coba Lagi';
$lang['mu_gridname']           = 'Nama file';
$lang['mu_gridsize']           = 'Ukuran';
$lang['mu_gridstat']           = 'Status';
$lang['mu_namespace']          = 'Namaspace';
$lang['mu_browse']             = 'Jelajah';
$lang['mu_ready']              = 'Siap untuk uplod';
$lang['mu_done']               = 'Selesai';
$lang['mu_fail']               = 'Gagal';
$lang['mu_authfail']           = 'sesi habis';
$lang['mu_progress']           = '@PCT@% uploaded';
$lang['mu_filetypes']          = 'Izinkan tipe file';

==> dokuwiki-2012.01.25.tgz: dokuwiki/inc/lang/id/lang.php <==
<?php
/**
 * Indonesian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author mubaidillah <mubaidillah@gmail.com>
 * @author Irwan Butar Butar <irwansah.putra@gmail.com>
 * @author Yustinus Waruwu <juswaruwu@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '\'';
$lang['singlequoteclosing']    = '\'';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Edit halaman ini';
$lang['btn_source']            = 'Lihat sumber halaman';
$lang['btn_show']              = 'Tampilkan halaman';
$lang['btn_create']            = 'Buat halaman baru';
$lang['btn_search']            = 'Cari';
$lang['btn_save']              = 'Simpan';
$lang['btn_preview']           = 'Preview';
$lang['btn_top']               = 'kembali ke atas';
$lang['btn_newer']             = '<< lebih lanjut';
$lang['btn_older']             = 'sebelumnya >>';
$lang['btn_revs']              = 'Revisi-revisi lama';
$lang['btn_recent']            = 'Perubahan terbaru';
$lang['btn_upload']            = 'Upload';
$lang['btn_cancel']            = 'Batal';
$lang['btn_index']             = 'Indeks';
$lang['btn_secedit']           = 'Edit';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Keluar';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Ubah';
$lang['btn_delete']            = 'Hapus';
$lang['btn_back']              = 'Kembali';
$lang['btn_backlink']          = 'Backlinks';
$lang['btn_backtomedia']       = 'Kembali ke Pilihan Mediafile';
$lang['btn_subscribe']         = 'Ikuti Perubahan';
$lang['btn_unsubscribe']       = 'Berhenti Ikuti Perubahan';
$lang['btn_profile']           = 'Ubah Profil';
$lang['btn_reset']             = 'Reset';
$lang['btn_resendpwd']         = 'Kirim password baru';
$lang['btn_draft']             = 'Edit draft';
$lang['btn_draftdel']          = 'Hapus draft';
$lang['btn_register']          = 'Daftar';
$lang['loggedinas']            = 'Login sebagai ';
$lang['user']                  = 'Username';
$lang['pass']                  = 'Password';
$lang['newpass']               = 'Password baru';
$lang['oldpass']               = 'Konfirmasi password';
$lang['passchk']               = 'sekali lagi';
$lang['remember']              = 'Ingat saya';
$lang['fullname']              = 'Nama lengkap';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Profil User';
$lang['badlogin']              = 'Maaf, username atau password salah.';
$lang['minoredit']             = 'Perubahan Minor';
$lang['draftdate']             = 'Simpan draft secara otomatis';
$lang['regmissing']            = 'Maaf, Anda harus mengisi semua field.';
$lang['reguexists']            = 'Maaf, user dengan user login ini telah ada.';
$lang['regsuccess']            = 'User telah didaftarkan dan password telah dikirim ke email Anda.';
$lang['regsuccess2']           = 'User telah dibuatkan.';
$lang['regmailfail']           = 'Kami menemukan kesalahan saat mengirimkan password ke alamat email Anda. Mohon hubungi administrator.';
$lang['regbadmail']            = 'Alamat email yang Anda masukkan tidak valid - jika menurut Anda hal ini adalah kesalahan sistem, mohon hubungi admin.';
$lang['regbadpass']            = 'Passwod yang dimasukkan tidak sama. Silahkan ulangi lagi.';
$lang['regpwmail']             = 'Password DokuWiki Anda';
$lang['reghere']               = 'Anda belum mempunyai account? silahkan ';
$lang['profna']                = 'Wiki ini tidak mengijinkan perubahan profil.';
$lang['profnochange']          = 'Tidak ada perubahan.';
$lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
$lang['profchanged']           = 'Profil User berhasil diubah.';
$lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
$lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
$lang['resendpwd']             = 'Kirim password baru untuk';
$lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
$lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
$lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
$lang['resendpwdconfirm']      = 'Link konfirmasi telah dikirim melalui email.';
$lang['resendpwdsuccess']      = 'Password baru Anda telah dikirim melalui email.';
$lang['txt_upload']            = 'File yang akan diupload';
$lang['txt_filename']          = 'Masukkan nama wiki (opsional)';
$lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
$lang['lockedby']              = 'Sedang dikunci oleh';
$lang['lockexpire']            = 'Penguncian artikel sampai dengan';
$lang['js']['willexpire']            = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
$lang['js']['notsavedyet']     = "Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?";
$lang['rssfailed']             = 'Error terjadi saat mengambil feed: ';
$lang['nothingfound']          = 'Tidak menemukan samasekali.';
$lang['mediaselect']           = 'Pilihan Mediafile';
$lang['fileupload']            = 'Mediafile Upload';
$lang['uploadsucc']            = 'Upload sukses';
$lang['uploadfail']            = 'Upload gagal. Apakah hak ijinnya salah?';
$lang['uploadwrong']           = 'Upload ditolak. Ekstensi file ini tidak diperbolehkan!';
$lang['uploadexist']           = 'File telah ada. Tidak mengerjakan apa-apa.';
$lang['uploadbadcontent']      = 'Isi file yang diupload tidak cocok dengan ekstensi file %s.';
$lang['uploadspam']            = 'File yang diupload diblok oleh spam blacklist.';
$lang['uploadxss']             = 'File yang diupload diblok karena kemungkinan isi yang berbahaya.';
$lang['deletesucc']            = 'File "%s" telah dihapus.';
$lang['deletefail']            = '"%s" tidak dapat dihapus - cek hak aksesnya.';
$lang['mediainuse']            = 'File "%s" belum dihapus - file ini sedang digunakan.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'File tersedia didalam';
$lang['js']['keepopen']        = 'Biarkan window terbuka dalam pemilihan';
$lang['js']['hidedetails']     = 'Sembunyikan detil';
$lang['mediausage']            = 'Gunakan sintaks berikut untuk me-refer ke file ini';
$lang['mediaview']             = 'Tampilkan file asli';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Upload file ke namespace ini. Untuk menbuat namespace baru, tambahkan namanya didepanpada nama file "Upload as" dipisahkan dengan titik dua (:).';
$lang['mediaextchange']        = 'Ektensi file berubah dari .%s ke .%s';
$lang['reference']             = 'Referensi untuk';
$lang['ref_inuse']             = 'File tidak dapat dihapus karena sedang digunakan oleh halaman:';
$lang['ref_hidden']            = 'Beberapa referensi ada didalam halaman yang tidak diijinkan untuk Anda baca.';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Matching pagenames';
$lang['toc']                   = 'Daftar isi';
$lang['current']               = 'sekarang';
$lang['yours']                 = 'Versi Anda';
$lang['diff']                  = 'Tampilkan perbedaan dengan versi sekarang';
$lang['diff2']                 = 'Tampilkan perbedaan diantara revisi terpilih';
$lang['line']                  = 'Baris';
$lang['breadcrumb']            = 'Jejak';
$lang['youarehere']            = 'Anda disini';
$lang['lastmod']               = 'Terakhir diubah';
$lang['by']                    = 'oleh';
$lang['deleted']               = 'terhapus';
$lang['created']               = 'dibuat';
$lang['restored']              = 'revisi lama ditampilkan kembali';
$lang['external_edit']         = 'Perubahan eksternal';
$lang['summary']               = 'Edit summary';
$lang['mail_newpage']          = 'Halaman ditambahkan:';
$lang['mail_changed']          = 'Halaman diubah:';
$lang['mail_new_user']         = 'User baru:';
$lang['mail_upload']           = 'Berkas di-upload:';
$lang['js']['nosmblinks']            = "Link ke share Windows hanya bekerja di Microsoft Internet Explorer.\nAnda masih dapat mengcopy and paste linknya.";
$lang['qb_bold']               = 'Tebal';
$lang['qb_italic']             = 'Miring';
$lang['qb_underl']             = 'Garis Bawah';
$lang['qb_code']               = 'Kode';
$lang['qb_strike']             = 'Text Tercoret';
$lang['qb_h1']                 = 'Level 1 Headline';
$lang['qb_h2']                 = 'Level 2 Headline';
$lang['qb_h3']                 = 'Level 3 Headline';
$lang['qb_h4']                 = 'Level 4 Headline';
$lang['qb_h5']                 = 'Level 5 Headline';
$lang['qb_link']               = 'Link Internal';
$lang['qb_extlink']            = 'Link External';
$lang['qb_hr']                 = 'Garis Horisontal';
$lang['qb_ol']                 = 'Item Berurutan';
$lang['qb_ul']                 = 'Item Tidak Berurutan';
$lang['qb_media']              = 'Tambahkan gambar atau file lain';
$lang['qb_sig']                = 'Sisipkan tanda tangan';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Karakter Khusus';
$lang['js']['del_confirm']           = 'Hapus tulisan ini?';
$lang['admin_register']        = 'Tambah user baru';
$lang['metaedit']              = 'Edit Metadata';
$lang['metasaveerr']           = 'Gagal menulis metadata';
$lang['metasaveok']            = 'Metadata tersimpan';
$lang['img_backto']            = 'Kembali ke';
$lang['img_title']             = 'Judul';
$lang['img_caption']           = 'Label';
$lang['img_date']              = 'Tanggal';
$lang['img_fname']             = 'Nama file';
$lang['img_fsize']             = 'Ukuran';
$lang['img_artist']            = 'Tukang foto';
$lang['img_copyr']             = 'Hakcipta';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Katakunci';
$lang['subscribe_success']     = 'Penambahan %s ke data subsripsi untuk %s';
$lang['subscribe_error']       = 'Gagal menambahkan %s ke data subsripsi untuk %s';
$lang['subscribe_noaddress']   = 'Tidak ditemukan alamat yang berhubungan dengan login Anda, Anda tidak dapat menambahkan daftar subscription';
$lang['unsubscribe_success']   = 'Menghapus %s dari daftar subscription untuk %s';
$lang['unsubscribe_error']     = 'Gagal menghapus %s dari daftar subscription untuk %s';
$lang['authmodfailed']         = 'Konfigurasi autentikasi user tidak valid. Harap informasikan admin Wiki Anda.';
$lang['authtempfail']          = 'Autentikasi user saat ini sedang tidak dapat digunakan. Jika kejadian ini berlanjut, Harap informasikan admin Wiki Anda.';
$lang['i_chooselang']          = 'Pilih bahasa';
$lang['i_installer']           = 'Instalasi DokuWiki';
$lang['i_wikiname']            = 'Nama Wiki';
$lang['i_enableacl']           = 'Aktifkan ACL (disarankan)';
$lang['i_problems']            = 'Terdapat beberapa kesalahan seperti berikut. Anda tidak dapat melanjutkan sampai kesalahan tersebut diperbaiki.';
$lang['i_modified']            = 'Untuk alasan keamanan, skrip ini hanya dapat dijalankan pada instalasi DikuWiki baru dan belum di modifikasi. Silahkan meng-ekstrak kembali berkasi dari halaman dowload, atau lihat   <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a> ';
$lang['i_funcna']              = 'Fungsi PHP <code>%s</code> tidak tersedia. Mungkin dinonaktifkan oleh layanan hosting Anda?';
$lang['i_phpver']              = 'Versi PHP Anda <code>%s</code> lebih rendah dari yang dibutuhkan <code>%s</code>. Mohon melakukan upgrade.';
$lang['i_permfail']            = '<code>%s</code> tidak dapat ditulis oleh DokuWiki. Anda harus memperbaiki konfigurasi hak akses untuk direktori tersebut.';
$lang['i_confexists']          = '<code>%s</code> sudah ada';
$lang['i_writeerr']            = 'Tidak dapat membuat <code>%s</code>. Anda harus memeriksa konfigurasi hak akses direktori/berkas dan membuatnya secara manual.';
$lang['i_badhash']             = 'dokuwiki.php tidak dikenal atau sudah diubah (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - tidak valid atau belum diisi';
$lang['i_success']             = 'Konfigurasi telah berhasil. Anda boleh menghapus berkas install.php sekarang. Lanjutkan ke <a href="doku.php">DokuWiki baru Anda</a>.';
$lang['i_failure']             = 'Terdapat beberapa kesalahan dalam menulis berkas konfigurasi. Anda harus memperbaikinnya sendiri sebelum dapat menggunakan <a href="doku.php">DokuWiki baru Anda</a>.';
$lang['i_policy']              = 'Policy ACL awal';
$lang['i_pol0']                = 'Wiki Terbuka (baca, tulis, upload untuk semua orang)';
$lang['i_pol1']                = 'Wiki Publik (baca untuk semua orang, tulis dan upload untuk pengguna terdaftar)';
$lang['i_pol2']                = 'Wiki Privat (baca, tulis dan upload hanya untuk pengguna terdaftar)';
$lang['i_retry']               = 'Coba Lagi';
